@@ -793,7 +793,7 @@ def _write_file(output, path, append):
 
 
 def parse_lin(file_text):
-    """Populate bridgeobjects objects from a pbn file."""
+    """Populate bridgeobjects objects from a lin file."""
     events = []
     event = Event()
     events.append(event)
@@ -829,16 +829,15 @@ def _parse_lin_board(line):
 def _parse_lin_hands(line_list, dealer):
     """Return a list of hands from lin text."""
     hands = {}
-    raw_hands = []
     dealer_index = SEATS.index(dealer)
-    hand_index = (dealer_index - 2) % 4
+    hand_index = (2 - dealer_index) % 4
     hand = Hand()
     for character in line_list:
         if character in Suit.SHORT_NAMES:
             suit_name = character
         elif character == ',':
             hands[hand_index] = hand
-            raw_hands.append(hand)
+            hands[SEATS[hand_index]] = hand
             hand = Hand()
             hand_index += 1
             hand_index %= 4
@@ -846,15 +845,13 @@ def _parse_lin_hands(line_list, dealer):
             card = Card(character, suit_name)
             hand.cards.append(card)
     hands[hand_index] = hand
-    raw_hands.append(hand)
     hand = Hand()
     hand_index += 1
     hand_index %= 4
 
-    raw_hands.append(Hand())
-    for card in Board.build_fourth_hand(hands):
-        hand.cards.append(card)
+    hand = Board.build_fourth_hand(hands)
     hands[hand_index] = hand
+    hands[SEATS[hand_index]] = hand
     return hands
 
 
@@ -893,4 +890,5 @@ class BoardAsString(object):
                 note = '[Note "{}:{}"]'.format(key, board.play_notes[key])
                 output.append(note)
             output.append('')
+        print(output)
         return output
